@@ -1,19 +1,32 @@
 # -*- encoding: utf-8 -*-
-# pilas engine - a video game framework.
+# Pilas engine - A video game framework.
 #
-# copyright 2010 - hugo ruscitti
-# license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
+# Copyright 2010 - Hugo Ruscitti
+# License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
 #
-# website - http://www.pilas-engine.com.ar
+# Website - http://www.pilas-engine.com.ar
 
 import pilas
 
 class Fondo(pilas.actores.Actor):
 
     def __init__(self, imagen):
+        self._eliminar_el_fondo_de_pantalla_actual()
         pilas.actores.Actor.__init__(self, imagen)
         self.z = 1000
 
+    def _eliminar_el_fondo_de_pantalla_actual(self):
+        fondos = [x for x in pilas.actores.todos if x.es_fondo()]
+        a_eliminar = []
+        for f in fondos:
+            a_eliminar.append(f)
+
+        for fondo in a_eliminar:
+            fondo.eliminar()
+
+    def es_fondo(self):
+        return True
+
 class Volley(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
 
@@ -44,6 +57,7 @@ class Tarde(Fondo):
 
     def __init__(self):
         Fondo.__init__(self, "fondos/tarde.jpg")
+        print "tarde fondo..."
 
 
 class Espacio(Fondo):
@@ -60,7 +74,7 @@ class Noche(Fondo):
 
 class Color(Fondo):
     "Pinta todo el fondo de un color uniforme."
-    
+
     def __init__(self, color):
         Fondo.__init__(self, "invisible.png")
         self.color = color
@@ -113,7 +127,7 @@ class Desplazamiento(Fondo):
             dx = self.posicion - self.posicion_anterior
             self.mover_capas(dx)
             self.posicion_anterior = self.posicion
-    
+
     def cuando_mueve_camara(self, evento):
         dx = evento.dx
 
