@@ -8,11 +8,12 @@
 
 import pilas
 import re
+from pilas.interfaz.base_interfaz import BaseInterfaz
 
-class IngresoDeTexto(pilas.actores.Actor):
+class IngresoDeTexto(BaseInterfaz):
     
     def __init__(self, texto_inicial="", x=0, y=0, ancho=300, limite_de_caracteres=20, icono=None):
-        pilas.actores.Actor.__init__(self, x=x, y=y)
+        BaseInterfaz.__init__(self, x=x, y=y)
         self.texto = texto_inicial
         self.cursor = ""
         self._cargar_lienzo(ancho)
@@ -27,14 +28,17 @@ class IngresoDeTexto(pilas.actores.Actor):
         self._actualizar_imagen()
         self.limite_de_caracteres = limite_de_caracteres
         self.cualquier_caracter()
-
+        
         pilas.eventos.pulsa_tecla.conectar(self.cuando_pulsa_una_tecla)
         pilas.mundo.agregar_tarea_siempre(0.40, self._actualizar_cursor)
         self.fijo = True
         
     def _actualizar_cursor(self):
-        if self.cursor == "":
-            self.cursor = "_"
+        if (self.tiene_el_foco):
+            if self.cursor == "":
+                self.cursor = "_"
+            else:
+                self.cursor = ""
         else:
             self.cursor = ""
             
@@ -51,21 +55,22 @@ class IngresoDeTexto(pilas.actores.Actor):
         self.caracteres_permitidos = re.compile("[a-z]+")
         
     def cuando_pulsa_una_tecla(self, evento):
-        if evento.codigo == '\x08' or evento.texto == '\x08':
-            # Indica que se quiere borrar un caracter
-            self.texto = self.texto[:-1]
-        else:
-            if len(self.texto) < self.limite_de_caracteres:
-                nuevo_texto = self.texto + evento.texto
-
-                if (self.caracteres_permitidos.match(evento.texto)):
-                    self.texto = self.texto + evento.texto
-                else:
-                    print "Rechazando el ingreso del caracter:", evento.texto
+        if (self.tiene_el_foco and self.activo):
+            if evento.codigo == '\x08' or evento.texto == '\x08':
+                # Indica que se quiere borrar un caracter
+                self.texto = self.texto[:-1]
             else:
-                print "Rechazando caracter por llegar al limite."
-        
-        self._actualizar_imagen()
+                if len(self.texto) < self.limite_de_caracteres:
+                    nuevo_texto = self.texto + evento.texto
+    
+                    if (self.caracteres_permitidos.match(evento.texto)):
+                        self.texto = self.texto + evento.texto
+                    else:
+                        print "Rechazando el ingreso del caracter:", evento.texto
+                else:
+                    print "Rechazando caracter por llegar al limite."
+            
+            self._actualizar_imagen()
         
     def _cargar_lienzo(self, ancho):
         self.imagen = pilas.imagenes.cargar_superficie(ancho, 30)
